@@ -5,15 +5,12 @@
 ##else: priors is a list of following objects:
         ##MuBeta:= prior mean for betas & intercepts; 
         ##SigmaBeta:= prior variance for betas & intercept;
-        ##MuAlpha:= prior mean for alpha; 
-        ##SigmaAlpha:= prior variance for alpha;
         ##MuZ; VarZ;
         ##PriorA; PriorB 
 ##TUNING PARAMETERS#######
 ##########################
 ##if tune = NULL => uses auto tuning
 ##else: tune is a list of following objects:
-       ##tuneAlpha = 0.9
        ##tuneBeta = vec, PP
        ##tuneInt = vec, len = 1
        ##tuneZ =  list( vec(len = nn[x]])) length of list = KK
@@ -21,20 +18,19 @@
 #library(MASS)
 HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
                       FullX = NULL, initialVals = NULL, priors = NULL, tune = NULL,
-        tuneIn = TRUE, TT = NULL,dd, niter)
+        tuneIn = TRUE,dd=2, niter)
 {
-  intervention <- 0
+
   #X and Y are provided as list. 
     if(class(Y) != 'list'){
 	if(dim(Y)[2] != 4){stop('Invalid data structure type')} }
-
-   # if(class(Y) == 'list' & class(Y[[1]]) != 'matrix' & class(Y[[1]]) != 'data.frame'){stop('Invalid data structure type')}
 	
     if(class(Y) == 'list'){ 
         KK = length(Y)
 	if(dim(Y[[1]])[1] == dim(Y[[1]])[2]){
             nn =sapply(1:length(Y),function(x) nrow(Y[[x]]))
-        nodenames=lapply(1:length(Y), function(x) rownames(Y[[x]]))}
+            nodenames=lapply(1:length(Y), function(x) rownames(Y[[x]]))
+        if(sum(sapply(nodenames, is.null))>=1){nodenames=lapply(1:length(Y), function(x) 1:dim(Y[[x]])[1])}}
 
 	if(dim(Y[[1]])[1] != dim(Y[[1]])[2] & dim(Y[[1]])[2] == 4){
 		nn = sapply(1:length(Y), function(x)length(unique(c(Y[[x]]$Receiver,Y[[x]]$Sender))))
@@ -137,8 +133,6 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
     if(is.null(priors)){
 	MuBeta= rep(0,(PP+1)) 
 	VarBeta = rep(1,(PP+1)) 
-        MuAlpha=0 
-        VarAlpha = 1 
         MuZ = c(0,0)
         VarZ = c(20,20)
         PriorA = 100
@@ -147,8 +141,6 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
 	if(class(priors) != 'list')(stop("priors must be of class list, if not NULL"))
 	MuBeta = priors$MuBeta
 	VarBeta = priors$VarBeta
-	MuAlpha = priors$MuAlpha
-	VarAlpha = priors$VarAlpha
 	MuZ = priors$MuZ
 	VarZ = priors$VarZ
 	PriorA = priors$PriorA
@@ -184,32 +176,23 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
         Z0 = unlist(Z00)
         beta0 = rnorm(PP,0,1)
         intercept0  = rnorm(1, 0,1)
-        if(intervention == 1){    alpha0=rnorm(1, 0, 1) }
         print("Starting Values Set")
     }else{
 	if(class(initialVals) != 'list')(stop("initialVals must be of class list, if not NULL"))
 	Z0 = initialVals$ZZ
 	beta0 = initialVals$beta
 	intercept0 = initialVals$intercept
-	if(intervention == 1){ alpha0 = initialVals$alpha}
-	}
-
-    if(intervention == 0){
-        alpha0 = 0
-        TT = rep(0, KK)
     }
 
 ###tuning parameters#####
     if(is.null(tune)){
             a.number = 5
-            tuneAlpha = 0.9
             tuneBeta = rep(1,PP)
             tuneInt = 0.2
             tuneZ =  lapply(1:KK,function(x) rep(1.2,nn[x]))          
             } else{
          	if(class(tune) != 'list')(stop("tune must be of class list, if not NULL"))
                  a.number = 1
-                 tuneAlpha = tune$tuneAlpha
                  tuneBeta = tune$tuneBeta
                  tuneInt = tune$tuneInt
                  tuneZ = tune$tuneZ
@@ -223,13 +206,9 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
         print('Tuning the Sampler')
         for(counter in 1:a.number)
 { 
-            rslt = MCMCfixedEF(nn=nn,PP=PP,KK=KK,dd=dd,XX = XX,YY = YY,ZZ = Z0,TT = TT,
-		beta = beta0 ,intercept = intercept0,alpha = alpha0,MuAlpha = MuAlpha,SigmaAlpha = VarAlpha,
-		MuBeta = MuBeta,SigmaBeta = VarBeta,MuZ = MuZ,VarZ = VarZ,tuneBetaAll = tuneBeta, tuneInt = tuneInt,
-		tuneAlpha = tuneAlpha,tuneZAll = unlist(tuneZ),niter = 200,PriorA = PriorA, PriorB = PriorB, 
-		intervention = intervention)
-
-            tuneAlpha = adjust.my.tune(tuneAlpha, rslt$acc$alpha,1)
+            rslt = MCMCfixedEF(nn=nn,PP=PP,KK=KK,dd=dd,XX = XX,YY = YY,ZZ = Z0,
+		beta = beta0 ,intercept = intercept0,
+		MuBeta = MuBeta,SigmaBeta = VarBeta,MuZ = MuZ,VarZ = VarZ,tuneBetaAll = tuneBeta, tuneInt = tuneInt,tuneZAll = unlist(tuneZ),niter = 200,PriorA = PriorA, PriorB = PriorB)
      	    tuneZ = lapply(1:KK,function(x)adjust.my.tune(tuneZ[[x]], rslt$acc$Z[[x]], 2))
             tuneBeta = adjust.my.tune(tuneBeta, rslt$acc$beta,1)
             tuneInt =  adjust.my.tune(tuneInt,rslt$acc$intercept,1)
@@ -243,11 +222,9 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
     print("Tuning is finished")  
 }
 
-    rslt = MCMCfixedEF(nn=nn,PP=PP,KK=KK,dd=dd,XX = XX,YY = YY,ZZ = Z0,TT = TT,
-		beta = beta0 ,intercept = intercept0,alpha = alpha0,MuAlpha = MuAlpha,SigmaAlpha = VarAlpha,
-		MuBeta = MuBeta,SigmaBeta = VarBeta,MuZ = MuZ,VarZ = VarZ,tuneBetaAll = tuneBeta, tuneInt = tuneInt, 
-		tuneAlpha = tuneAlpha,tuneZAll = unlist(tuneZ),niter = niter,PriorA = PriorA, PriorB = PriorB, 
-		intervention = intervention)
+    rslt = MCMCfixedEF(nn=nn,PP=PP,KK=KK,dd=dd,XX = XX,YY = YY,ZZ = Z0,
+		beta = beta0 ,intercept = intercept0,
+		MuBeta = MuBeta,SigmaBeta = VarBeta,MuZ = MuZ,VarZ = VarZ,tuneBetaAll = tuneBeta, tuneInt = tuneInt,tuneZAll = unlist(tuneZ),niter = niter,PriorA = PriorA, PriorB = PriorB)
     
     ##Procrutes transformation on the final draws of the latent positions
     ##
@@ -263,28 +240,14 @@ HLSMfixedEF= function(Y,edgeCov = NULL, receiverCov = NULL,senderCov =NULL,
     
 
     rslt$call = match.call()
-    if(noCOV == TRUE & intervention == 0){
+    if(noCOV == TRUE){
 		rslt$tune = list(tuneZ = tuneZ, tuneInt = tuneInt)	
-		rslt$draws$Beta = NA
-		rslt$draws$Alpha = NA
-    }
-    if(noCOV == TRUE & intervention == 1){
-	    rslt$tune = list(tuneAlpha = tuneAlpha, tuneZ = tuneZ,tuneInt = tuneInt)
-	    rslt$draws$Beta = NA	
-	}
-    if(noCOV == FALSE & intervention == 0){
-	    rslt$tune = list(tuneBeta = tuneBeta, tuneZ = tuneZ,tuneInt = tuneInt)
-	    rslt$draws$Alpha = NA
-}
-    if(noCOV == FALSE & intervention == 1){
-	    rslt$tune = list(tuneBeta = tuneBeta,tuneAlpha=tuneAlpha,tuneZ = tuneZ,tuneInt = tuneInt)
-}	
+		rslt$draws$Beta = NA}
+
+    if(noCOV == FALSE){
+	    rslt$tune = list(tuneBeta = tuneBeta, tuneZ = tuneZ,tuneInt = tuneInt)}
+	
     class(rslt) = 'HLSM'
     rslt
 }
 
-
-    
-
-
-
