@@ -1,7 +1,8 @@
 summary.HLSM = function(object,...){
 	if(class(object) != 'HLSM'){stop('input must be of class HLSM')}
-
+warning("Run HLSMdiag to assess convergence and thinning before reporting")
 	call = object$call
+type= get_HLSM_type(list(object))
 
 	Betas = getBeta(object, ...)
 	if(!is.null(Betas)){
@@ -20,6 +21,7 @@ summary.HLSM = function(object,...){
 	}
 	}else(est.slopes = NA)
 
+if(type!='LSM.estInt'){
 	Intercept = getIntercept(object,...)
 	if(class(Intercept)[1] == 'matrix'){
 		est.intercept = t(sapply(1:ncol(Intercept), function(y) data.frame(min = round(min(Intercept[,y]),3), max = round(max(Intercept[,y]),3), est.mean = round(mean(Intercept[,y]),3), sd = round(sd(Intercept[,y]),3), q.25 = round(quantile(Intercept[,y],0.025),3), q.975 = round(quantile(Intercept[,y],0.975),3) )) )
@@ -27,12 +29,9 @@ summary.HLSM = function(object,...){
 		est.intercept = data.frame(min = round(min(Intercept),3), max = round(max(Intercept),3), est.mean = round(mean(Intercept),3), sd = round(sd(Intercept),3), q.025 = round(quantile(Intercept,0.025),3), q.975 = round(quantile(Intercept, 0.975),3) )
       }
 	
-	Alphas = getAlpha(object,...)
-	if(!is.null(Alphas)){
-			est.alpha = data.frame(min = round(min(Alphas),3), max = round(max(Alphas),3), est.mean = round(mean(Alphas),3), sd = round(sd(Alphas),3), q.025 = round(quantile(Alphas,0.025),3), q.975 = round(quantile(Alphas, 0.975),3) ) 
-	}else(est.alpha = NA)
-
-	res =  list(call = object$call,est.intercept = est.intercept, est.slopes = est.slopes, est.alpha = est.alpha)
+	res =  list(call = object$call,est.intercept = est.intercept, est.slopes = est.slopes)
+	}else{res =  list(call = object$call,est.slopes = est.slopes)}
+		
 
     class(res) = 'summary.HLSM'
     res
